#
# spec file for package python-Genshi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define oldpython python
%{?sle15_python_module_pythons}
Name:           python-Genshi
Version:        0.7.9
Release:        2.5
Summary:        A toolkit for generation of output for the web
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://genshi.edgewall.org/
Source:         https://files.pythonhosted.org/packages/source/G/Genshi/Genshi-%{version}.tar.gz
BuildRequires:  %{python_module Babel}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module xml}
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  python-rpm-macros
Requires:       python-Babel
Requires:       python-six
Requires:       python-xml
%ifpython2
Obsoletes:      %{oldpython}-genshi < %{version}
Provides:       %{oldpython}-genshi = %{version}
%endif
%python_subpackages

%description
Genshi is a Python library that provides an integrated set of
components for parsing, generating, and processing HTML, XML or
other textual content for output generation on the web. The major
feature is a template language, which is heavily inspired by Kid.

%package -n %{name}-doc
Summary:        A toolkit for generation of output for the web - Documentation
Group:          Development/Libraries/Python
Provides:       %{python_module Genshi-doc = %{version}}
BuildArch:      noarch

%description -n %{name}-doc
Genshi is a Python library that provides an integrated set of
components for parsing, generating, and processing HTML, XML or
other textual content for output generation on the web. The major
feature is a template language, which is heavily inspired by Kid.

This package contains documentation and examples.

%prep
%autosetup -p1 -n Genshi-%{version}

%build
%python_build

%install
%python_install
# Fix python-bytecode-inconsistent-mtime
pushd %{buildroot}%{python_sitearch}
find . -name '*.pyc' -exec rm -f '{}' ';'
python%python_bin_suffix -m compileall *.py ';'
popd
# remove accidentally installed source files
%python_expand find %{buildroot}%{$python_sitearch}/genshi -name '*.c' -delete
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pyunittest_arch -v genshi.tests.suite

%files %{python_files}
%license COPYING
%doc ChangeLog README.md
%{python_sitearch}/genshi/
%{python_sitearch}/Genshi-%{version}*-info

%files -n %{name}-doc
%doc doc
%doc examples

%changelog
* Wed Sep 25 2024 ecsos <ecsos@opensuse.org>
- Fix build error under Leap.
* Mon Jul 22 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.7.9
  * Add Python 3.12 to CI matrix and fix Python 3.12 support. (#77)
  * Add Python 3.13 beta to CI. (#81)
  * Add badges to the README. (#82)
- from version 0.7.8
  * Do not merge sub directives if they have not been changed. (#53)
  * Silence deprecation warnings from attempting to import Ellipsis and
    Str (which are needed to support older Pythons). (#73)
  * Remove fallback to distutils, patching of bdist_egg and use of doctools. (#74)
  * Clarify the escaping in _URL_FINDER. (#76)
  * Fix installation with setuptools >= 60. (#68)
- Rename README.txt to README.md in %%files section
* Sun Apr 23 2023 Matej Cepl <mcepl@suse.com>
- Switch documentation to be within the main package.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Tue Aug  2 2022 Otto Hollmann <otto.hollmann@suse.com>
- Update to 0.7.7:
  * Declared setuptools as the build backend (#65)
  * Fixed deprecation warnings caused by escape sequences in regex pattern
    strings (#63)
- Changes from 0.7.6:
  * Added support for Python 3.10 and 3.11 (#54, #56, #58)
  * Replaced assertEquals with assertEqual. assertEquals was deprecated in
    Python 3.2. (#42)
  * Removed used of element.getchildren() which has been removed from the Python
    standard library elementtree in Python 3.9. (#57)
  * Added support for Python 3.10 by using CodeType.replace in
    `build_code_chunk` to make code object updates more robust against changes
    in CodeType. (#49)
  * Moved tests and releases workflows to GitHub Actions (#61, #51)
  * Fixed reference leak in Markup.join C implementation. (#47)
  * Sort directives only by directive index. Previously they were sorted by the
    class, namespace and arguments of the directives. This was acceptable in
    Python 2, but is a bug in Python 3 since some the arguments may not be
    comparable. (#44)
  * Add support for msgctxt to i18n. (#13)
  * Implemented skipping of empty attributes during translation to match the
    behaviour during translation extraction (i.e. don't try to translate empty
    strings that are not extracted). (#38)
  * Ported setuptools options to declarative config in setup.cfg. (#40)
  * Removed used of deprecated setuptools Feature in setup.py. (#39)
- Removed patches, already in upstream:
  * Genshi-pr39-fix-setuptools-extension.patch
  * Genshi-pr49-fix-python310-tests.patch
* Sat Dec 11 2021 Ben Greiner <code@bnavigator.de>
- add Genshi-pr49-fix-python310-tests.patch - gh#edgewall/genshi#49
* Sat Jun 26 2021 Ben Greiner <code@bnavigator.de>
- Add Genshi-pr39-fix-setuptools-extension.patch in order to fix
  failing the c extension with an updated setuptools
  gh#edgewall/genshi#36
* Fri Mar 19 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.7.5
  * Fix handling of slices containing function call, variable name
    and attribute lookup AST nodes in Python 3.9 in template
    scripts (template expressions already correctly handled these
    cases). Thank you to Roger Leigh for finding this issue and
    contributing the fix for it.
  * C speedup module now available for Python >= 3.3. Support was
    added for PEP 393 (flexible string representation). Thank you
    to Inada Naoki for contributing this major enhancement.
  * Remove the custom 2to3 fixers (no longer used since the
    removal of 2to3 in 0.7.4).
- Release 0.7.4
  * Add support for deprecation of ast classes slice, Index and
    ExtSlice in Python 3.9. See https://bugs.python.org/issue34822
    for details of the changes.
  * Update the project URL in setup.py to point to GitHub.
  * Remove use of 2to3 for generating Python 3 compatible code.
* Wed Apr  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in python2 packages when installing docs
* Tue Jun 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.3:
  * Add support for PEP 570 (positional-only keyword parameters)
* Mon Apr 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.2:
  * Add support for Python 3.8.
* Mon Mar  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.1:
  * many bugfixes all around and support for new pythons
- Merged all our patches:
  * python-Genshi-bug-602-python35-support.patch
  * python-Genshi-bug-602-python35-support-python27-fix.patch
  * python-genshi-py3-escape-sequence-doctest.patch
  * python-genshi-py37-stopiteration.patch
  * python-Genshi-0.7-disable-speedups-for-python34.patch
  * python-Genshi-0.7-isstring-helper.patch
  * python-Genshi-0.7-python34-ast-support.patch
  * python-Genshi-0.7-sanitizer-test-fixes.patch
  * changeset_r1242.diff
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Aug  7 2018 tchvatal@suse.com
- Add patches to build on python 3.7:
  * python-genshi-py3-escape-sequence-doctest.patch
  * python-genshi-py37-stopiteration.patch
* Thu Apr  6 2017 jmatejek@suse.com
- always build as arch-dependent
- build docs as a single noarch package
* Thu Apr  6 2017 aloisio@gmx.com
- Added python-Genshi-0.7-disable-speedups-for-python34.patch,
  python-Genshi-0.7-isstring-helper.patch,
  python-Genshi-0.7-python34-ast-support.patch,
  python-Genshi-0.7-sanitizer-test-fixes.patch,
  python-Genshi-bug-602-python35-support.patch,
  python-Genshi-bug-602-python35-support-python27-fix.patch
- Enabled tests
* Thu Apr  6 2017 toddrme2178@gmail.com
- Update singlespec build
- Use pypi download url
* Mon Dec 19 2016 jmatejek@suse.com
- update for multipython build
* Fri Jul 24 2015 seife+obs@b1-systems.com
- fix build on non-SUSE distributions
* Tue Feb 17 2015 opensuse@dstoecker.de
- backport fix for bug 566 (pop from empty) from 0.7 devel (changeset_r1242.diff)
* Tue Oct 22 2013 toddrme2178@gmail.com
- Update to 0.7
  * Add support for Python 3.1, 3.2 and 3.3 (via 2to3) and for PyPy. The
  majority of the coding was done in a sprint run by the Cape Town Python
  Users Group with financial assistance from the Python Software Foundation.
  * Default input and output encodings changed from UTF-8 to None (i.e. unicode
  strings).
  * Skip Mako benchmarks if Mako isn't installed (rather than failing
  completely).
- Update to 0.6.1
  * Security fix to enhance sanitizing of CSS in style attributes. Genshi's
  `HTMLSanitizer` disallows style attributes by default (this remains
  unchanged) and warns against such attacks in its documentation, but
  the provided CSS santizing is now less lacking (see #455).
  * Fix for error in how `HTMLFormFiller` would handle `textarea` elements if
  no value was not supplied form them.
  * The `HTMLFormFiller` now correctly handles check boxes and radio buttons
  with an empty `value` attribute.
  * Template `Context` objects now have a `.copy` method.
  * Added a simple `tox.ini` file for using tox to test against multiple
  verions of Python.
  * Fix for bug in `QName` comparison (see #413).
  * Fix for bug in handling of trailing events in match template matches
  (see #399).
  * Fix i18n namespace declaration in documentation (see #400).
  * Fix for bug in caching of events in serializers by no longer caching
  `(TEXT, Markup)` events (see #429).
  * Fix handling of `None` by `Markup.escape` in `_speedups.c` (see #439).
  * Fix handling of internal state by match templates (relevant when multiple
  templates match the same part of the stream, see #370).
  * Fix handling of multiple events between or on either side of start and end
  tags in translated messages (see #404).
  * Fix test failures caused by changes in HTMLParser in Python 2.7 (see #501).
  * Fix infinite loop in interplotation lexing that was introduced by a change
  in Python 2.7's tokenizer (see #540).
  * Fix handling of processing instructions without data (see #368).
  * Updated MANIFEST.in so as not to rely on build from Subersion 1.6.
* Thu Sep  1 2011 saschpe@suse.de
- Renamed to python-Genshi (from python-Genshi)
- Changed license to BSD-3-Clause (SPDX style) from BSD3c
- Fixed doc-file-dependency rpmlint issue
* Thu Mar  3 2011 saschpe@suse.de
- Spec file cleanup
  * Proper SUSE changes file and removed changelog from spec
  * Added proper license header
  * Package files COPYING, README.txt and docs and examples
- Split of documentation package
* Sun Apr 25 2010 bitdealer@gmail.com
- Updated to 0.6
* Mon Aug  4 2008 dannoritzer@web.de
- Updated to 0.5.1
* Thu Feb 28 2008 dannoritzer@web.de
- Fixed build errors
- Updated to 0.4.4
* Mon Oct 15 2007 nix@opensuse.org
- Clean up spec file and change name to python-geneshi
* Sun Jul 22 2007 dannoritzer@web.de
- Initial package
